@@ -1,5 +1,5 @@
 package Scalar::Defer;
-$Scalar::Defer::VERSION = '0.05';
+$Scalar::Defer::VERSION = '0.06';
 
 use 5.006;
 use strict;
@@ -12,11 +12,16 @@ our @EXPORT = qw( lazy defer force );
 private _defer => my %_defer;
 
 BEGIN {
-    overload::OVERLOAD( 0 => fallback => 1, map {
-        $_ => sub { &{$_defer{ Class::InsideOut::id $_[0] }} }
-    } qw( bool "" 0+ ${} @{} %{} &{} *{} ));
-
     no strict 'refs';
+    no warnings 'redefine';
+
+    # Set up overload for the package "0".
+    overload::OVERLOAD(
+        '0' => fallback => 1, map {
+            $_ => sub { &{$_defer{ id $_[0] }} }
+        } qw( bool "" 0+ ${} @{} %{} &{} *{} )
+    );
+
     *{"0::AUTOLOAD"} = sub {
         my $meth = our $AUTOLOAD;
         my $idx = index($meth, '::');
@@ -24,13 +29,13 @@ BEGIN {
             $meth = substr($meth, $idx + 2);
         }
 
-        unshift @_, force(shift());
+        unshift @_, force(shift(@_));
         goto &{$_[0]->can($meth)};
     };
 
     foreach my $sym (keys %UNIVERSAL::) {
         *{"0::$sym"} = sub {
-            unshift @_, force(shift());
+            unshift @_, force(shift(@_));
             goto &{$_[0]->can($sym)};
         };
     }
